@@ -23,22 +23,18 @@
 #ifndef MOLLETNETWORK_EXPORT_H
 #define MOLLETNETWORK_EXPORT_H
 
-// KDE
-#include <kdemacros.h>
-
-
 #ifndef MOLLETNETWORK_EXPORT
   // building the library?
 # if defined(MAKE_MOLLETNETWORK_LIB)
 #  define MOLLETNETWORK_EXPORT Q_DECL_EXPORT
   // using the library
 # else
-#  define MOLLETNETWORK_EXPORT KDE_IMPORT
+#  define MOLLETNETWORK_EXPORT Q_DECL_IMPORT
 # endif
 #endif
 
 # ifndef MOLLETNETWORK_EXPORT_DEPRECATED
-#  define MOLLETNETWORK_EXPORT_DEPRECATED KDE_DEPRECATED MOLLETNETWORK_EXPORT
+#  define MOLLETNETWORK_EXPORT_DEPRECATED QT_DEPRECATED MOLLETNETWORK_EXPORT
 # endif
 
 #endif
